==> 1.0.3.tar.gz: doc/DnsApi.md <==
# forestvpn_api.api.DnsApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**lookup**](DnsApi.md#lookup) | **POST** /dns/lookup | DNS Lookup


# **lookup**
> Lookup lookup(request)

DNS Lookup

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

var api_instance = DnsApi();
var request = LookupRequest(); // LookupRequest | 

try { 
    var result = api_instance.lookup(request);
    print(result);
} catch (e) {
    print("Exception when calling DnsApi->lookup: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**LookupRequest**](LookupRequest.md)|  | [optional] 

### Return type

[**Lookup**](Lookup.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> 1.2.4.tar.gz: doc/DnsApi.md <==
# forestvpn_api.api.DnsApi

## Load the API package
```dart
import 'package:forestvpn_api/api.dart';
```

All URIs are relative to *https://api.forestvpn.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**lookup**](DnsApi.md#lookup) | **POST** /dns/lookup | DNS Lookup


# **lookup**
> Lookup lookup(request)

DNS Lookup

### Example 
```dart
import 'package:forestvpn_api/api.dart';
// TODO Configure API key authorization: Bearer
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKey = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//defaultApiClient.getAuthentication<ApiKeyAuth>('Bearer').apiKeyPrefix = 'Bearer';

final api_instance = DnsApi();
final request = LookupRequest(); // LookupRequest | 

try { 
    final result = api_instance.lookup(request);
    print(result);
} catch (e) {
    print('Exception when calling DnsApi->lookup: $e\n');
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request** | [**LookupRequest**](LookupRequest.md)|  | [optional] 

### Return type

[**Lookup**](Lookup.md)

### Authorization

[Bearer](../README.md#Bearer)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
